$(document).ready(function () {
  let firstNameErr = $('#firstNameErr');
  let lastNameErr = $('#lastNameErr');
  let emailErr = $('#emailErr');
  let pinErr = $('#pinErr');
  let confirmPinErr = $('#confirmPinErr');
  let errorOccured = $('#signupError');
  let signupSuccess = $('#signupSuccess');
  let base_url = 'https://crustsolutionsgh.com:8208';
  let anErrorOccurredString = 'An error occurred. Please try again.';

  errorOccured.hide();
  signupSuccess.hide()

  // signup form handling
  $('#form-signup').on('submit', function (e) {
    e.preventDefault();

    let fname = $('#first_name').val();
    let lname = $('#last_name').val();
    let email = $('#signup-email').val();
    let pin = $('#pin').val();
    let confirm_pin = $('#confirm_pin').val();

    if (validateSignupForm(fname, lname, email, pin, confirm_pin)) {
      sendSignupFormData(fname, lname, email, pin);
    } else {
        
    }
  });

  // validating values from signup form
  function validateSignupForm(fname, lname, email, pin, confirm_pin) {
    // let numbers = /^[0-9]+$/;

    firstNameErr.hide();
    lastNameErr.hide();
    emailErr.hide();
    pinErr.hide();
    confirmPinErr.hide();
    errorOccured.hide();

    if (
      fname === '' &&
      lname === '' &&
      email === '' &&
      pin === '' &&
      confirm_pin === ''
    ) {
      displayErrorOccurred('All fields are required.');
      return false;
    }

    if (fname === '') {
      firstNameErr.empty();
      firstNameErr.append('First name is required.');
      firstNameErr.show();
      return false;
    }

    if (fname.length < 2) {
      firstNameErr.empty();
      firstNameErr.append('First name should be at least 2 characters.');
      firstNameErr.show();
      return false;
    }

    if (lname === '') {
      lastNameErr.empty();
      lastNameErr.append('Last name is required.');
      lastNameErr.show();
      return false;
    }

    if (lname.length < 2) {
      lastNameErr.empty();
      lastNameErr.append('First name should be at least 2 characters.');
      lastNameErr.show();
      return false;
    }

    if (email === '') {
      emailErr.empty();
      emailErr.append('Email is required.');
      emailErr.show();
      return false;
    }

    if (email.indexOf('@', 0) < 0) {
      emailErr.empty();
      emailErr.append('Email is not valid.');
      emailErr.show();
      return false;
    }

    if (email.indexOf('.', 0) < 0) {
      emailErr.empty();
      emailErr.append('Email is not valid.');
      emailErr.show();
      return false;
    }

    if (pin === '') {
      pinErr.empty();
      pinErr.append('PIN is required.');
      pinErr.show();
      return false;
    }

    if (isNaN(pin)) {
      pinErr.empty();
      pinErr.append('PIN should be only numbers.');
      pinErr.show();
      return false;
    }

    if (pin.length !== 6) {
      pinErr.empty();
      pinErr.append('PIN should be 6 digits.');
      pinErr.show();
      return false;
    }

    if (pin !== confirm_pin) {
      confirmPinErr.empty();
      confirmPinErr.append('PINs do no match.');
      confirmPinErr.show();
      return false;
    }

    return true;
  }

  // send form data using ajax request
  function sendSignupFormData(fname, lname, email, pin) {
    $(".loader_div").show();
    let data = {
      first_name: fname,
      last_name: lname,
      email: email,
      pin: pin,
    };
    let signup_endpoint = base_url + '/newUser';

    $.ajax({
      dataType: 'JSON',
      type: 'POST',
      url: signup_endpoint,
      data: JSON.stringify(data),
      secure: true,
      success: function (data) {
        logData(data);
         $(".loader_div").hide();
        if (data.status) {
          if (data.status === '0') {
            // successful // 
            displaySuccessMsg('Signup successful. Please login to check your subscription.')
            $('#form-signup').trigger('reset');
          } else {
            displayErrorOccurred(anErrorOccurredString);
          }
        } else {
          displayErrorOccurred(anErrorOccurredString);
        }
      },
      error: function (err) {
        logData(err)
        $(".loader_div").hide();
        displayErrorOccurred(anErrorOccurredString);
      },
    });
  }

  // display error occurred alert
  function displayErrorOccurred(msg) {
    errorOccured.empty();
    errorOccured.append(msg);
    errorOccured.show();
  }

  // display error occurred alert
  function displaySuccessMsg(msg) {
    signupSuccess.empty();
    signupSuccess.append(msg);
    signupSuccess.show();
  }

  function logData(data) {
    // console.log(data);
  }

});
